@@ -107,8 +107,8 @@ partialInvariance <- function(fit, type, free = NULL, fix = NULL, refgroup = 1,
 	result <- fixCon <- freeCon <- NULL
 	estimates <- NULL
 	listFreeCon <- listFixCon <- list()		
-	beta <- coef(fit1)
-	beta0 <- coef(fit0)
+	beta <- lavaan::coef(fit1)
+	beta0 <- lavaan::coef(fit0)
 	waldMat <- matrix(0, ngroups - 1, length(beta))
 	if(numType == 1) {
 		if(!is.null(free) | !is.null(fix)) {
@@ -164,8 +164,8 @@ partialInvariance <- function(fit, type, free = NULL, fix = NULL, refgroup = 1,
 			namept0 <- paramNameFromPt(pt0)
 			fit0 <- refit(pt0, fit0)
 			fit1 <- refit(pt1, fit1)
-			beta <- coef(fit1)
-			beta0 <- coef(fit0)
+			beta <- lavaan::coef(fit1)
+			beta0 <- lavaan::coef(fit0)
 			waldMat <- matrix(0, ngroups - 1, length(beta))
 			varfree <- setdiff(varfree, c(free, fix))
 		}
@@ -220,10 +220,10 @@ partialInvariance <- function(fit, type, free = NULL, fix = NULL, refgroup = 1,
 			if(!is(tryresult0, "try-error")) {
 				compresult0 <- try(modelcomp0 <- lavaan::lavTestLRT(tempfit0, fit0, method = method), silent = TRUE)
 				if(!is(compresult0, "try-error"))  freeCon[pos,] <- c(unlist(modelcomp0[2,5:7]), deltacfi(tempfit0, fit0))
-				loadVal <- getValue(temp0, coef(tempfit0), pt0$lhs[runnum], pt0$op[runnum], pt0$rhs[runnum], 1:ngroups)
+				loadVal <- getValue(temp0, lavaan::coef(tempfit0), pt0$lhs[runnum], pt0$op[runnum], pt0$rhs[runnum], 1:ngroups)
 				estimates[pos, 2:ncol(estimates)] <- loadVal
-				facVal <- getValue(temp0, coef(tempfit0), pt0$lhs[runnum], "~~", pt0$lhs[runnum], 1:ngroups)
-				totalVal <- sapply(fitted.values(tempfit0), function(x, v) x$cov[v, v], v = pt0$rhs[runnum])
+				facVal <- getValue(temp0, lavaan::coef(tempfit0), pt0$lhs[runnum], "~~", pt0$lhs[runnum], 1:ngroups)
+				totalVal <- sapply(lavaan::fitted.values(tempfit0), function(x, v) x$cov[v, v], v = pt0$rhs[runnum])
 				names(facVal) <- names(totalVal) <- grouplab
 				ifelse(poolvar, refFacVal <- poolVariance(facVal, neach), refFacVal <- facVal[refgroup])
 				ifelse(poolvar, refTotalVal <- poolVariance(totalVal, neach), refTotalVal <- totalVal[refgroup])
@@ -237,10 +237,10 @@ partialInvariance <- function(fit, type, free = NULL, fix = NULL, refgroup = 1,
 				zLoadVal <- atanh(stdLoadVal)
 				esz[pos,] <- zLoadVal[2:ngroups] - zLoadVal[1]
 				
-				facMean <- getValue(temp0, coef(tempfit0), pt0$lhs[runnum], "~1", "", 1:ngroups)
+				facMean <- getValue(temp0, lavaan::coef(tempfit0), pt0$lhs[runnum], "~1", "", 1:ngroups)
 				wlow <- min(facMean - fbound * sqrt(facVal))
 				whigh <- max(facMean + fbound * sqrt(facVal))
-				intVal <- getValue(temp0, coef(tempfit0), pt0$rhs[runnum], "~1", "", 1:ngroups)
+				intVal <- getValue(temp0, lavaan::coef(tempfit0), pt0$rhs[runnum], "~1", "", 1:ngroups)
 				loadVal <- loadVal[grouporder]
 				intVal <- intVal[grouporder]
 				loaddiff <- loadVal[2:ngroups] - loadVal[1]
@@ -294,10 +294,10 @@ partialInvariance <- function(fit, type, free = NULL, fix = NULL, refgroup = 1,
 			if(!is(tryresult0, "try-error")) {
 				compresult0 <- try(modelcomp0 <- lavaan::lavTestLRT(tempfit0, fit0, method = method), silent = TRUE)
 				if(!is(compresult0, "try-error")) freeCon[pos,] <- c(unlist(modelcomp0[2,5:7]), deltacfi(tempfit0, fit0))
-				loadVal <- getValue(temp0, coef(tempfit0), pt0$lhs[runnum], pt0$op[runnum], pt0$rhs[runnum], 1:ngroups)
+				loadVal <- getValue(temp0, lavaan::coef(tempfit0), pt0$lhs[runnum], pt0$op[runnum], pt0$rhs[runnum], 1:ngroups)
 				estimates[pos, 2:ncol(estimates)] <- loadVal
-				facVal <- getValue(temp0, coef(tempfit0), pt0$lhs[runnum], "~~", pt0$lhs[runnum], 1:ngroups)
-				totalVal <- sapply(fitted.values(tempfit0), function(x, v) x$cov[v, v], v = pt0$rhs[runnum])
+				facVal <- getValue(temp0, lavaan::coef(tempfit0), pt0$lhs[runnum], "~~", pt0$lhs[runnum], 1:ngroups)
+				totalVal <- sapply(lavaan::fitted.values(tempfit0), function(x, v) x$cov[v, v], v = pt0$rhs[runnum])
 				names(facVal) <- names(totalVal) <- grouplab
 				ifelse(poolvar, refFacVal <- poolVariance(facVal, neach), refFacVal <- facVal[refgroup])
 				ifelse(poolvar, refTotalVal <- poolVariance(totalVal, neach), refTotalVal <- totalVal[refgroup])
@@ -311,10 +311,10 @@ partialInvariance <- function(fit, type, free = NULL, fix = NULL, refgroup = 1,
 				zLoadVal <- atanh(stdLoadVal)
 				esz[pos,] <- zLoadVal[2:ngroups] - zLoadVal[1]
 				
-				facMean <- getValue(temp0, coef(tempfit0), pt0$lhs[runnum], "~1", "", 1:ngroups)
+				facMean <- getValue(temp0, lavaan::coef(tempfit0), pt0$lhs[runnum], "~1", "", 1:ngroups)
 				wlow <- min(facMean - fbound * sqrt(facVal))
 				whigh <- max(facMean + fbound * sqrt(facVal))
-				intVal <- getValue(temp0, coef(tempfit0), pt0$rhs[runnum], "~1", "", 1:ngroups)
+				intVal <- getValue(temp0, lavaan::coef(tempfit0), pt0$rhs[runnum], "~1", "", 1:ngroups)
 				loadVal <- loadVal[grouporder]
 				intVal <- intVal[grouporder]
 				loaddiff <- loadVal[2:ngroups] - loadVal[1]
@@ -385,8 +385,8 @@ partialInvariance <- function(fit, type, free = NULL, fix = NULL, refgroup = 1,
 			namept0 <- paramNameFromPt(pt0)
 			fit0 <- refit(pt0, fit0)
 			fit1 <- refit(pt1, fit1)
-			beta <- coef(fit1)
-			beta0 <- coef(fit0)
+			beta <- lavaan::coef(fit1)
+			beta0 <- lavaan::coef(fit0)
 			waldMat <- matrix(0, ngroups - 1, length(beta))
 			varfree <- setdiff(varfree, c(free, fix))
 		}
@@ -436,9 +436,9 @@ partialInvariance <- function(fit, type, free = NULL, fix = NULL, refgroup = 1,
 			if(!is(tryresult0, "try-error")) {
 				compresult0 <- try(modelcomp0 <- lavaan::lavTestLRT(tempfit0, fit0, method = method), silent = TRUE)
 				if(!is(compresult0, "try-error"))  freeCon[pos,] <- c(unlist(modelcomp0[2,5:7]), deltacfi(tempfit0, fit0))
-				intVal <- getValue(temp0, coef(tempfit0), pt0$lhs[runnum], pt0$op[runnum], pt0$rhs[runnum], 1:ngroups)
+				intVal <- getValue(temp0, lavaan::coef(tempfit0), pt0$lhs[runnum], pt0$op[runnum], pt0$rhs[runnum], 1:ngroups)
 				estimates[pos, 2:ncol(estimates)] <- intVal
-				totalVal <- sapply(fitted.values(tempfit0), function(x, v) x$cov[v, v], v = pt0$lhs[runnum])
+				totalVal <- sapply(lavaan::fitted.values(tempfit0), function(x, v) x$cov[v, v], v = pt0$lhs[runnum])
 				ifelse(poolvar, refTotalVal <- poolVariance(totalVal, neach), refTotalVal <- totalVal[refgroup])
 				stdIntVal <- intVal / sqrt(refTotalVal)
 				stdestimates[pos,] <- stdIntVal
@@ -494,9 +494,9 @@ partialInvariance <- function(fit, type, free = NULL, fix = NULL, refgroup = 1,
 			if(!is(tryresult0, "try-error")) {
 				compresult0 <- try(modelcomp0 <- lavaan::lavTestLRT(tempfit0, fit0, method = method), silent = TRUE)
 				if(!is(compresult0, "try-error"))  freeCon[pos,] <- c(unlist(modelcomp0[2,5:7]), deltacfi(tempfit0, fit0))
-				intVal <- getValue(temp0, coef(tempfit0), pt0$lhs[runnum], pt0$op[runnum], pt0$rhs[runnum], 1:ngroups)
+				intVal <- getValue(temp0, lavaan::coef(tempfit0), pt0$lhs[runnum], pt0$op[runnum], pt0$rhs[runnum], 1:ngroups)
 				estimates[pos, 2:ncol(estimates)] <- intVal
-				totalVal <- sapply(fitted.values(tempfit0), function(x, v) x$cov[v, v], v = pt0$lhs[runnum])
+				totalVal <- sapply(lavaan::fitted.values(tempfit0), function(x, v) x$cov[v, v], v = pt0$lhs[runnum])
 				ifelse(poolvar, refTotalVal <- poolVariance(totalVal, neach), refTotalVal <- totalVal[refgroup])
 				stdIntVal <- intVal / sqrt(refTotalVal)
 				stdestimates[pos,] <- stdIntVal
@@ -534,8 +534,8 @@ partialInvariance <- function(fit, type, free = NULL, fix = NULL, refgroup = 1,
 			namept0 <- paramNameFromPt(pt0)
 			fit0 <- refit(pt0, fit0)
 			fit1 <- refit(pt1, fit1)
-			beta <- coef(fit1)
-			beta0 <- coef(fit0)
+			beta <- lavaan::coef(fit1)
+			beta0 <- lavaan::coef(fit0)
 			waldMat <- matrix(0, ngroups - 1, length(beta))
 			varfree <- setdiff(varfree, c(free, fix))
 		}
@@ -572,9 +572,9 @@ partialInvariance <- function(fit, type, free = NULL, fix = NULL, refgroup = 1,
 			if(!is(tryresult0, "try-error")) {
 				compresult0 <- try(modelcomp0 <- lavaan::lavTestLRT(tempfit0, fit0, method = method), silent = TRUE)
 				if(!is(compresult0, "try-error"))  freeCon[i,] <- c(unlist(modelcomp0[2,5:7]), deltacfi(tempfit0, fit0))
-				errVal <- getValue(temp0, coef(tempfit0), pt0$lhs[runnum], pt0$op[runnum], pt0$rhs[runnum], 1:ngroups)
+				errVal <- getValue(temp0, lavaan::coef(tempfit0), pt0$lhs[runnum], pt0$op[runnum], pt0$rhs[runnum], 1:ngroups)
 				estimates[i, 2:ncol(estimates)] <- errVal
-				totalVal <- sapply(fitted.values(tempfit0), function(x, v) x$cov[v, v], v = pt0$rhs[runnum])
+				totalVal <- sapply(lavaan::fitted.values(tempfit0), function(x, v) x$cov[v, v], v = pt0$rhs[runnum])
 				ifelse(poolvar, refTotalVal <- poolVariance(totalVal, neach), refTotalVal <- totalVal[refgroup])
 				stdErrVal <- errVal / sqrt(refTotalVal)
 				stdestimates[i,] <- stdErrVal
@@ -620,8 +620,8 @@ partialInvariance <- function(fit, type, free = NULL, fix = NULL, refgroup = 1,
 			namept0 <- paramNameFromPt(pt0)
 			fit0 <- refit(pt0, fit0)
 			fit1 <- refit(pt1, fit1)
-			beta <- coef(fit1)
-			beta0 <- coef(fit0)
+			beta <- lavaan::coef(fit1)
+			beta0 <- lavaan::coef(fit0)
 			waldMat <- matrix(0, ngroups - 1, length(beta))
 			varfree <- setdiff(varfree, c(free, fix))
 		}
@@ -663,9 +663,9 @@ partialInvariance <- function(fit, type, free = NULL, fix = NULL, refgroup = 1,
 			if(!is(tryresult0, "try-error")) {
 				compresult0 <- try(modelcomp0 <- lavaan::lavTestLRT(tempfit0, fit0, method = method), silent = TRUE)
 				if(!is(compresult0, "try-error"))  freeCon[i,] <- c(unlist(modelcomp0[2,5:7]), deltacfi(tempfit0, fit0))
-				meanVal <- getValue(temp0, coef(tempfit0), pt0$lhs[runnum], pt0$op[runnum], pt0$rhs[runnum], 1:ngroups)
+				meanVal <- getValue(temp0, lavaan::coef(tempfit0), pt0$lhs[runnum], pt0$op[runnum], pt0$rhs[runnum], 1:ngroups)
 				estimates[i, 2:ncol(estimates)] <- meanVal
-				facVal <- getValue(temp0, coef(tempfit0), pt0$lhs[runnum], "~~", pt0$lhs[runnum], 1:ngroups)
+				facVal <- getValue(temp0, lavaan::coef(tempfit0), pt0$lhs[runnum], "~~", pt0$lhs[runnum], 1:ngroups)
 				ifelse(poolvar, refFacVal <- poolVariance(facVal, neach), refFacVal <- facVal[refgroup])
 				stdMeanVal <- meanVal / sqrt(refFacVal)
 				stdestimates[i,] <- stdMeanVal
